<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>LinetypeSettings</name>
    <message>
        <location filename="../LinetypeSettings.js" line="+25"/>
        <source>Defaults for New Drawings</source>
        <translation>Standards für neue Zeichnungen</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>1.0</source>
        <translation type="obsolete">1.0</translation>
    </message>
    <message>
        <source>Default Linetype</source>
        <translation type="obsolete">Vorgabe Linientyp</translation>
    </message>
    <message>
        <location line="-2"/>
        <location line="+2"/>
        <source>Linetype</source>
        <translation>Linientyp</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+19"/>
        <source>Global Linetype Scale:</source>
        <translation>Globale Linientyp Skalierung:</translation>
    </message>
    <message>
        <location line="+35"/>
        <source>Scale of linetypes matches the scale of each viewport</source>
        <translation>Skalierung der Linientypen entspricht der Skalierung der einzelnen Ansichtsfenster</translation>
    </message>
</context>
</TS>
